@@ -42,6 +42,7 @@ import gettext
 gettext.textdomain("pykickstart")
 _ = lambda x: gettext.ldgettext("pykickstart", x)
 
+import types
 import warnings
 from pykickstart.errors import *
 from pykickstart.ko import *
@@ -94,7 +95,7 @@ class KickstartCommand(KickstartObject):
         # members from the kwargs list before we start processing it.  This
         # ensures that subclasses don't continue to recognize arguments that
         # were removed.
-        for arg in filter(lambda k: kwargs.has_key(k), self.removedKeywords):
+        for arg in filter(kwargs.has_key, self.removedKeywords):
             kwargs.pop(arg)
 
     def __call__(self, *args, **kwargs):
@@ -172,7 +173,7 @@ class DeprecatedCommand(KickstartCommand):
         if self.__class__ is KickstartCommand:
             raise TypeError, "DeprecatedCommand is an abstract class."
 
-        """Create a new DeprecatedCommand instance."""
+        # Create a new DeprecatedCommand instance.
         KickstartCommand.__init__(self, writePriority, *args, **kwargs)
 
     def __str__(self):
@@ -193,16 +194,15 @@ class BaseHandler(KickstartObject):
        class.  These subclasses are what users will interact with for parsing,
        extracting data, and writing out kickstart files.  This is an abstract
        class.
-    """
 
-    """version -- The version this syntax handler supports.  This is set by
+       version -- The version this syntax handler supports.  This is set by
                   a class attribute of a BaseHandler subclass and is used to
                   set up the command dict.  It is for read-only use.
     """
     version = None
 
-    def __init__(self, mapping={}, dataMapping={}, commandUpdates={},
-                 dataUpdates={}, *args, **kwargs):
+    def __init__(self, mapping=None, dataMapping=None, commandUpdates=None,
+                 dataUpdates=None, *args, **kwargs):
         """Create a new BaseHandler instance.  This method must be provided by
            all subclasses, but subclasses must call BaseHandler.__init__ first.
 
@@ -290,26 +290,26 @@ class BaseHandler(KickstartObject):
 
         return retval
 
-    def _insertSorted(self, list, obj):
-        length = len(list)
+    def _insertSorted(self, lst, obj):
+        length = len(lst)
         i = 0
 
         while i < length:
             # If the two classes have the same name, it's because we are
             # overriding an existing class with one from a later kickstart
             # version, so remove the old one in favor of the new one.
-            if obj.__class__.__name__ > list[i].__class__.__name__:
+            if obj.__class__.__name__ > lst[i].__class__.__name__:
                 i += 1
-            elif obj.__class__.__name__ == list[i].__class__.__name__:
-                list[i] = obj
+            elif obj.__class__.__name__ == lst[i].__class__.__name__:
+                lst[i] = obj
                 return
-            elif obj.__class__.__name__ < list[i].__class__.__name__:
+            elif obj.__class__.__name__ < lst[i].__class__.__name__:
                 break
 
         if i >= length:
-            list.append(obj)
+            lst.append(obj)
         else:
-            list.insert(i, obj)
+            lst.insert(i, obj)
 
     def _setCommand(self, cmdObj):
         # Add an attribute on this version object.  We need this to provide a
@@ -329,22 +329,25 @@ class BaseHandler(KickstartObject):
             else:
                 self._writeOrder[cmdObj.writePriority] = [cmdObj]
 
-    def _registerCommands(self, mapping={}, dataMapping={}, commandUpdates={},
-                          dataUpdates={}):
-        if mapping == {}:
+    def _registerCommands(self, mapping=None, dataMapping=None, commandUpdates=None,
+                          dataUpdates=None):
+        if mapping == {} or mapping == None:
             from pykickstart.handlers.control import commandMap
             cMap = commandMap[self.version]
         else:
             cMap = mapping
 
-        if dataMapping == {}:
+        if dataMapping == {} or dataMapping == None:
             from pykickstart.handlers.control import dataMap
             dMap = dataMap[self.version]
         else:
             dMap = dataMapping
 
-        cMap.update(commandUpdates)
-        dMap.update(dataUpdates)
+        if type(commandUpdates) == types.DictType:
+            cMap.update(commandUpdates)
+
+        if type(dataUpdates) == types.DictType:
+            dMap.update(dataUpdates)
 
         for (cmdName, cmdClass) in cMap.iteritems():
             # First make sure we haven't instantiated this command handler
@@ -372,7 +375,7 @@ class BaseHandler(KickstartObject):
         for (dataName, dataClass) in dMap.iteritems():
             setattr(self, dataName, dataClass)
 
-    def dispatcher(self, args, lineno, include=None):
+    def dispatcher(self, args, lineno):
         """Call the appropriate KickstartCommand handler for the current line
            in the kickstart file.  A handler for the current command should
            be registered, though a handler of None is not an error.  Returns
@@ -380,8 +383,6 @@ class BaseHandler(KickstartObject):
 
            args    -- A list of arguments to the current command
            lineno  -- The line number in the file, for error reporting
-           include -- The path to any file %included immediately before the
-                      current command
         """
         cmd = args[0]
 
@@ -394,17 +395,12 @@ class BaseHandler(KickstartObject):
 
             # The parser returns the data object that was modified.  This could
             # be a BaseData subclass that should be put into a list, or it
-            # could be the command handler object itself.  If there's an
-            # include that preceeds either, we need to then associated it with
-            # the returned object.
+            # could be the command handler object itself.
             obj = self.commands[cmd].parse(args[1:])
             lst = self.commands[cmd].dataList()
             if lst is not None:
                 lst.append(obj)
 
-            if include is not None:
-                obj.preceededInclude = include
-
             return obj
 
     def maskAllExcept(self, lst):
