@@ -23,7 +23,6 @@ from pykickstart.errors import *
 from pykickstart.options import *
 
 import gettext
-import string
 import warnings
 _ = lambda x: gettext.ldgettext("pykickstart", x)
 
@@ -71,9 +70,9 @@ class F8_RepoData(FC6_RepoData):
         if self.cost:
             retval += " --cost=%s" % self.cost
         if self.includepkgs:
-            retval += " --includepkgs=\"%s\"" % string.join(self.includepkgs, ",")
+            retval += " --includepkgs=\"%s\"" % ",".join(self.includepkgs)
         if self.excludepkgs:
-            retval += " --excludepkgs=\"%s\"" % string.join(self.excludepkgs, ",")
+            retval += " --excludepkgs=\"%s\"" % ",".join(self.excludepkgs)
 
         return retval
 
@@ -124,10 +123,16 @@ class F14_RepoData(F13_RepoData):
 
         return retval
 
+RHEL6_RepoData = F14_RepoData
+
+F15_RepoData = F14_RepoData
+
 class FC6_Repo(KickstartCommand):
     removedKeywords = KickstartCommand.removedKeywords
     removedAttrs = KickstartCommand.removedAttrs
 
+    urlRequired = True
+
     def __init__(self, writePriority=0, *args, **kwargs):
         KickstartCommand.__init__(self, writePriority, *args, **kwargs)
         self.op = self._getParser()
@@ -160,7 +165,7 @@ class FC6_Repo(KickstartCommand):
         if opts.baseurl and opts.mirrorlist:
             raise KickstartValueError, formatErrorMsg(self.lineno, msg=_("Only one of --baseurl and --mirrorlist may be specified for repo command."))
 
-        if not opts.baseurl and not opts.mirrorlist:
+        if self.urlRequired and not opts.baseurl and not opts.mirrorlist:
             raise KickstartValueError, formatErrorMsg(self.lineno, msg=_("One of --baseurl or --mirrorlist must be specified for repo command."))
 
         rd = self.handler.RepoData()
@@ -235,3 +240,10 @@ class F14_Repo(F13_Repo):
         op.add_option("--noverifyssl", action="store_true", default=False)
         return op
 
+RHEL6_Repo = F14_Repo
+
+class F15_Repo(F14_Repo):
+    removedKeywords = F14_Repo.removedKeywords
+    removedAttrs = F14_Repo.removedAttrs
+
+    urlRequired = False
