@@ -20,12 +20,11 @@
 from pykickstart.version import *
 from pykickstart.commands import *
 
-"""This map is keyed on kickstart syntax version as provided by
-   pykickstart.version.  Within each sub-dict is a mapping from command name
-   to the class that handles it.  This is an onto mapping - that is, multiple
-   command names can map to the same class.  However, the Handler will ensure
-   that only one instance of each class ever exists.
-"""
+# This map is keyed on kickstart syntax version as provided by
+# pykickstart.version.  Within each sub-dict is a mapping from command name
+# to the class that handles it.  This is an onto mapping - that is, multiple
+# command names can map to the same class.  However, the Handler will ensure
+# that only one instance of each class ever exists.
 commandMap = {
     FC3: {
         "auth": authconfig.FC3_Authconfig,
@@ -704,6 +703,126 @@ commandMap = {
         "zfcp": zfcp.F14_ZFCP,
     },
 
+    # based on f14
+    F15: {
+        "auth": authconfig.FC3_Authconfig,
+        "authconfig": authconfig.FC3_Authconfig,
+        "autopart": autopart.F12_AutoPart,
+        "autostep": autostep.FC3_AutoStep,
+        "bootloader": bootloader.F15_Bootloader,
+        "cdrom": method.F14_Method,
+        "clearpart": clearpart.FC3_ClearPart,
+        "cmdline": displaymode.FC3_DisplayMode,
+        "device": device.F8_Device,
+        "deviceprobe": deviceprobe.FC3_DeviceProbe,
+        "dmraid": dmraid.FC6_DmRaid,
+        "driverdisk": driverdisk.F14_DriverDisk,
+        "fcoe": fcoe.F13_Fcoe,
+        "firewall": firewall.F14_Firewall,
+        "firstboot": firstboot.FC3_Firstboot,
+        "graphical": displaymode.FC3_DisplayMode,
+        "group": group.F12_Group,
+        "halt": reboot.FC6_Reboot,
+        "harddrive": method.F14_Method,
+        "ignoredisk": ignoredisk.F14_IgnoreDisk,
+        "install": upgrade.F11_Upgrade,
+        "iscsi": iscsi.F10_Iscsi,
+        "iscsiname": iscsiname.FC6_IscsiName,
+        "keyboard": keyboard.FC3_Keyboard,
+        "lang": lang.FC3_Lang,
+        "logging": logging.FC6_Logging,
+        "logvol": logvol.F15_LogVol,
+        "mediacheck": mediacheck.FC4_MediaCheck,
+        "monitor": monitor.F10_Monitor,
+        "multipath": multipath.FC6_MultiPath,
+        "network": network.F9_Network,
+        "nfs": method.F14_Method,
+        "part": partition.F14_Partition,
+        "partition": partition.F14_Partition,
+        "poweroff": reboot.FC6_Reboot,
+        "raid": raid.F15_Raid,
+        "reboot": reboot.FC6_Reboot,
+        "repo": repo.F15_Repo,
+        "rescue": rescue.F10_Rescue,
+        "rootpw": rootpw.F8_RootPw,
+        "selinux": selinux.FC3_SELinux,
+        "services": services.FC6_Services,
+        "shutdown": reboot.FC6_Reboot,
+        "skipx": skipx.FC3_SkipX,
+        "sshpw": sshpw.F13_SshPw,
+        "text": displaymode.FC3_DisplayMode,
+        "timezone": timezone.FC6_Timezone,
+        "updates": updates.F7_Updates,
+        "upgrade": upgrade.F11_Upgrade,
+        "url": method.F14_Method,
+        "user": user.F12_User,
+        "vnc": vnc.F9_Vnc,
+        "volgroup": volgroup.FC3_VolGroup,
+        "xconfig": xconfig.F14_XConfig,
+        "zerombr": zerombr.F9_ZeroMbr,
+        "zfcp": zfcp.F14_ZFCP,
+    },
+
+    # based on f15
+    F16: {
+        "auth": authconfig.FC3_Authconfig,
+        "authconfig": authconfig.FC3_Authconfig,
+        "autopart": autopart.F12_AutoPart,
+        "autostep": autostep.FC3_AutoStep,
+        "bootloader": bootloader.F15_Bootloader,
+        "cdrom": method.F14_Method,
+        "clearpart": clearpart.FC3_ClearPart,
+        "cmdline": displaymode.FC3_DisplayMode,
+        "device": device.F8_Device,
+        "deviceprobe": deviceprobe.FC3_DeviceProbe,
+        "dmraid": dmraid.FC6_DmRaid,
+        "driverdisk": driverdisk.F14_DriverDisk,
+        "fcoe": fcoe.F13_Fcoe,
+        "firewall": firewall.F14_Firewall,
+        "firstboot": firstboot.FC3_Firstboot,
+        "graphical": displaymode.FC3_DisplayMode,
+        "group": group.F12_Group,
+        "halt": reboot.FC6_Reboot,
+        "harddrive": method.F14_Method,
+        "ignoredisk": ignoredisk.F14_IgnoreDisk,
+        "install": upgrade.F11_Upgrade,
+        "iscsi": iscsi.F10_Iscsi,
+        "iscsiname": iscsiname.FC6_IscsiName,
+        "keyboard": keyboard.FC3_Keyboard,
+        "lang": lang.FC3_Lang,
+        "logging": logging.FC6_Logging,
+        "logvol": logvol.F15_LogVol,
+        "mediacheck": mediacheck.FC4_MediaCheck,
+        "monitor": monitor.F10_Monitor,
+        "multipath": multipath.FC6_MultiPath,
+        "network": network.F16_Network,
+        "nfs": method.F14_Method,
+        "part": partition.F14_Partition,
+        "partition": partition.F14_Partition,
+        "poweroff": reboot.FC6_Reboot,
+        "raid": raid.F15_Raid,
+        "reboot": reboot.FC6_Reboot,
+        "repo": repo.F15_Repo,
+        "rescue": rescue.F10_Rescue,
+        "rootpw": rootpw.F8_RootPw,
+        "selinux": selinux.FC3_SELinux,
+        "services": services.FC6_Services,
+        "shutdown": reboot.FC6_Reboot,
+        "skipx": skipx.FC3_SkipX,
+        "sshpw": sshpw.F13_SshPw,
+        "text": displaymode.FC3_DisplayMode,
+        "timezone": timezone.FC6_Timezone,
+        "updates": updates.F7_Updates,
+        "upgrade": upgrade.F11_Upgrade,
+        "url": method.F14_Method,
+        "user": user.F12_User,
+        "vnc": vnc.F9_Vnc,
+        "volgroup": volgroup.FC3_VolGroup,
+        "xconfig": xconfig.F14_XConfig,
+        "zerombr": zerombr.F9_ZeroMbr,
+        "zfcp": zfcp.F14_ZFCP,
+    },
+
     # based on fc1
     RHEL3: {
         "auth": authconfig.FC3_Authconfig,
@@ -869,8 +988,8 @@ commandMap = {
         "authconfig": authconfig.FC3_Authconfig,
         "autopart": autopart.F12_AutoPart,
         "autostep": autostep.FC3_AutoStep,
-        "bootloader": bootloader.F12_Bootloader,
-        "cdrom": method.F13_Method,
+        "bootloader": bootloader.RHEL6_Bootloader,
+        "cdrom": method.RHEL6_Method,
         "clearpart": clearpart.FC3_ClearPart,
         "cmdline": displaymode.FC3_DisplayMode,
         "device": device.F8_Device,
@@ -883,7 +1002,7 @@ commandMap = {
         "graphical": displaymode.FC3_DisplayMode,
         "group": group.F12_Group,
         "halt": reboot.FC6_Reboot,
-        "harddrive": method.F13_Method,
+        "harddrive": method.RHEL6_Method,
         "ignoredisk": ignoredisk.RHEL6_IgnoreDisk,
         "install": upgrade.F11_Upgrade,
         "interactive": interactive.FC3_Interactive,
@@ -896,14 +1015,14 @@ commandMap = {
         "mediacheck": mediacheck.FC4_MediaCheck,
         "monitor": monitor.F10_Monitor,
         "multipath": multipath.FC6_MultiPath,
-        "network": network.F9_Network,
-        "nfs": method.F13_Method,
+        "network": network.RHEL6_Network,
+        "nfs": method.RHEL6_Method,
         "part": partition.F12_Partition,
         "partition": partition.F12_Partition,
         "poweroff": reboot.FC6_Reboot,
         "raid": raid.F13_Raid,
         "reboot": reboot.FC6_Reboot,
-        "repo": repo.F13_Repo,
+        "repo": repo.RHEL6_Repo,
         "rescue": rescue.F10_Rescue,
         "rootpw": rootpw.F8_RootPw,
         "selinux": selinux.FC3_SELinux,
@@ -915,7 +1034,7 @@ commandMap = {
         "timezone": timezone.FC6_Timezone,
         "updates": updates.F7_Updates,
         "upgrade": upgrade.F11_Upgrade,
-        "url": method.F13_Method,
+        "url": method.RHEL6_Method,
         "user": user.F12_User,
         "vnc": vnc.F9_Vnc,
         "volgroup": volgroup.FC3_VolGroup,
@@ -925,12 +1044,11 @@ commandMap = {
     }
 }
 
-"""This map is keyed on kickstart syntax version as provided by
-   pykickstart.version.  Within each sub-dict is a mapping from a data object
-   name to the class that provides it.  This is a bijective mapping - that is,
-   each name maps to exactly one data class and all data classes have a name.
-   More than one instance of each class is allowed to exist, however.
-"""
+# This map is keyed on kickstart syntax version as provided by
+# pykickstart.version.  Within each sub-dict is a mapping from a data object
+# name to the class that provides it.  This is a bijective mapping - that is,
+# each name maps to exactly one data class and all data classes have a name.
+# More than one instance of each class is allowed to exist, however.
 dataMap = {
     FC3: {
         "DriverDiskData": driverdisk.FC3_DriverDiskData,
@@ -1100,6 +1218,42 @@ dataMap = {
         "VolGroupData": volgroup.FC3_VolGroupData,
         "ZFCPData": zfcp.F14_ZFCPData,
     },
+    F15: {
+        "DriverDiskData": driverdisk.F14_DriverDiskData,
+        "DeviceData": device.F8_DeviceData,
+        "DmRaidData": dmraid.FC6_DmRaidData,
+        "FcoeData": fcoe.F13_FcoeData,
+        "GroupData": group.F12_GroupData,
+        "IscsiData": iscsi.F10_IscsiData,
+        "LogVolData": logvol.F15_LogVolData,
+        "MultiPathData": multipath.FC6_MultiPathData,
+        "NetworkData": network.F8_NetworkData,
+        "PartData": partition.F14_PartData,
+        "RaidData": raid.F15_RaidData,
+        "RepoData": repo.F15_RepoData,
+        "SshPwData": sshpw.F13_SshPwData,
+        "UserData": user.F12_UserData,
+        "VolGroupData": volgroup.FC3_VolGroupData,
+        "ZFCPData": zfcp.F14_ZFCPData,
+    },
+    F16: {
+        "DriverDiskData": driverdisk.F14_DriverDiskData,
+        "DeviceData": device.F8_DeviceData,
+        "DmRaidData": dmraid.FC6_DmRaidData,
+        "FcoeData": fcoe.F13_FcoeData,
+        "GroupData": group.F12_GroupData,
+        "IscsiData": iscsi.F10_IscsiData,
+        "LogVolData": logvol.F15_LogVolData,
+        "MultiPathData": multipath.FC6_MultiPathData,
+        "NetworkData": network.F16_NetworkData,
+        "PartData": partition.F14_PartData,
+        "RaidData": raid.F15_RaidData,
+        "RepoData": repo.F15_RepoData,
+        "SshPwData": sshpw.F13_SshPwData,
+        "UserData": user.F12_UserData,
+        "VolGroupData": volgroup.FC3_VolGroupData,
+        "ZFCPData": zfcp.F14_ZFCPData,
+    },
     RHEL3: {
         "DriverDiskData": driverdisk.FC3_DriverDiskData,
         "LogVolData": logvol.FC3_LogVolData,
@@ -1141,10 +1295,10 @@ dataMap = {
         "IscsiData": iscsi.F10_IscsiData,
         "LogVolData": logvol.F12_LogVolData,
         "MultiPathData": multipath.FC6_MultiPathData,
-        "NetworkData": network.F8_NetworkData,
+        "NetworkData": network.RHEL6_NetworkData,
         "PartData": partition.F12_PartData,
         "RaidData": raid.F13_RaidData,
-        "RepoData": repo.F13_RepoData,
+        "RepoData": repo.RHEL6_RepoData,
         "SshPwData": sshpw.F13_SshPwData,
         "UserData": user.F12_UserData,
         "VolGroupData": volgroup.FC3_VolGroupData,
