@@ -34,7 +34,6 @@ This module exports several important classes:
 import os
 import shlex
 import sys
-import string
 import tempfile
 from copy import copy
 from optparse import *
@@ -56,9 +55,6 @@ STATE_PACKAGES = 2
 STATE_SCRIPT_HDR = 3
 STATE_SCRIPT = 4
 
-# FIXME:  This is a hack until I have time to think about making the parser
-# itself support multiple syntax versions.  Yes, I know this means it will
-# never be fixed.
 ver = DEVEL
 
 def _preprocessStateMachine (provideLineFn):
@@ -89,14 +85,14 @@ def _preprocessStateMachine (provideLineFn):
 
         # Try to pull down the remote file.
         try:
-            ksurl = string.split(ll, ' ')[1]
+            ksurl = ll.split(' ')[1]
         except:
             raise KickstartParseError, formatErrorMsg(lineno, msg=_("Illegal url for %%ksappend: %s") % ll)
 
         try:
             url = grabber.urlopen(ksurl)
         except grabber.URLGrabError, e:
-            raise IOError, formatErrorMsg(lineno, msg=_("Unable to open %%ksappend file: %s") % e.strerror)
+            raise KickstartError, formatErrorMsg(lineno, msg=_("Unable to open %%ksappend file: %s") % e.strerror)
         else:
             # Sanity check result.  Sometimes FTP doesn't catch a file
             # is missing.
@@ -118,28 +114,28 @@ def _preprocessStateMachine (provideLineFn):
     os.close(outF)
     return outName
 
-def preprocessFromString (str):
+def preprocessFromString (s):
     """Preprocess the kickstart file, provided as the string str.  This
         method is currently only useful for handling %ksappend lines,
         which need to be fetched before the real kickstart parser can be
         run.  Returns the location of the complete kickstart file.
     """
-    i = iter(str.splitlines(True) + [""])
-    rc = _preprocessStateMachine (lambda: i.next())
+    i = iter(s.splitlines(True) + [""])
+    rc = _preprocessStateMachine (i.next)
     return rc
 
-def preprocessKickstart (file):
+def preprocessKickstart (f):
     """Preprocess the kickstart file, given by the filename file.  This
         method is currently only useful for handling %ksappend lines,
         which need to be fetched before the real kickstart parser can be
         run.  Returns the location of the complete kickstart file.
     """
     try:
-        fh = urlopen(file)
+        fh = urlopen(f)
     except grabber.URLGrabError, e:
-        raise IOError, formatErrorMsg(0, msg=_("Unable to open input kickstart file: %s") % e.strerror)
+        raise KickstartError, formatErrorMsg(0, msg=_("Unable to open input kickstart file: %s") % e.strerror)
 
-    rc = _preprocessStateMachine (lambda: fh.readline())
+    rc = _preprocessStateMachine (fh.readline)
     fh.close()
     return rc
 
@@ -170,7 +166,7 @@ class Script(KickstartObject):
                           pykickstart.constants.
         """
         KickstartObject.__init__(self, *args, **kwargs)
-        self.script = string.join(script, "")
+        self.script = "".join(script)
 
         self.interp = kwargs.get("interp", "/bin/sh")
         self.inChroot = kwargs.get("inChroot", False)
@@ -181,10 +177,7 @@ class Script(KickstartObject):
 
     def __str__(self):
         """Return a string formatted for output to a kickstart file."""
-        if self.preceededInclude is not None:
-            retval = "\n%%include %s\n" % self.preceededInclude
-        else:
-            retval = ""
+        retval = ""
 
         if self.type == KS_SCRIPT_PRE:
             retval += '\n%pre'
@@ -311,12 +304,7 @@ class Packages(KickstartObject):
             if pkgs == "":
                 return ""
 
-        if self.preceededInclude is not None:
-            retval = "\n%%include %s\n" % self.preceededInclude
-        else:
-            retval = ""
-
-        retval += "\n%packages"
+        retval = "\n%packages"
 
         if self.default:
             retval += " --default"
@@ -434,8 +422,10 @@ class KickstartParser:
         self.handler = handler
         self.currentdir = {}
         self.missingIncludeIsFatal = missingIncludeIsFatal
-        self._reset()
 
+        self._state = STATE_COMMANDS
+        self._script = None
+        self._includeDepth = 0
         self._line = ""
 
         self.version = self.handler.version
@@ -448,14 +438,13 @@ class KickstartParser:
         self._state = STATE_COMMANDS
         self._script = None
         self._includeDepth = 0
-        self._preceededInclude = None
 
     def addScript (self):
         """Create a new Script instance and add it to the Version object.  This
            is called when the end of a script section is seen and may be
            overridden in a subclass if necessary.
         """
-        if string.join(self._script["body"]).strip() == "":
+        if " ".join(self._script["body"]).strip() == "":
             return
 
         kwargs = {"interp": self._script["interp"],
@@ -465,10 +454,6 @@ class KickstartParser:
                   "errorOnFail": self._script["errorOnFail"],
                   "type": self._script["type"]}
 
-        if self._preceededInclude is not None:
-            kwargs["preceededInclude"] = self._preceededInclude
-            self._preceededInclude = None
-
         s = Script (self._script["body"], **kwargs)
 
         if self.handler:
@@ -491,8 +476,7 @@ class KickstartParser:
         if self.handler:
             self.handler.currentCmd = args[0]
             self.handler.currentLine = self._line
-            retval = self.handler.dispatcher(args, lineno, self._preceededInclude)
-            self._preceededInclude = None
+            retval = self.handler.dispatcher(args, lineno)
 
             return retval
 
@@ -532,10 +516,6 @@ class KickstartParser:
         if opts.instLangs:
             self.handler.packages.instLangs = opts.instLangs
 
-        if self._preceededInclude is not None:
-            self.handler.packages.preceededInclude = self._preceededInclude
-            self._preceededInclude = None
-
     def handleScriptHdr (self, lineno, args):
         """Process the arguments to a %pre/%post/%traceback header for later
            setting on a Script instance once the end of the script is found.
@@ -601,7 +581,7 @@ class KickstartParser:
                 # Have we found a state transition?  If so, we still want
                 # to split.  Otherwise, args won't be set but we'll fall through
                 # all the way to the last case.
-                if self._line != "" and string.split(self._line.lstrip())[0] in \
+                if self._line != "" and self._line.lstrip().split()[0] in \
                    ["%end", "%post", "%pre", "%traceback", "%include", "%packages", "%ksappend"]:
                     args = shlex.split(self._line)
                 else:
@@ -618,8 +598,6 @@ class KickstartParser:
                 args = shlex.split(self._line)
 
             if args and args[0] == "%include":
-                self._preceededInclude = args[1]
-
                 # This case comes up primarily in ksvalidator.
                 if not self.followIncludes:
                     needLine = True
@@ -632,7 +610,7 @@ class KickstartParser:
 
                     try:
                         self.readKickstart (args[1], reset=False)
-                    except IOError:
+                    except KickstartError:
                         # Handle the include file being provided over the
                         # network in a %pre script.  This case comes up in the
                         # early parsing in anaconda.
@@ -696,7 +674,7 @@ class KickstartParser:
                     raise KickstartParseError, formatErrorMsg(lineno)
                 else:
                     needLine = True
-                    self.addPackages (string.rstrip(self._line))
+                    self.addPackages(self._line.rstrip())
 
             elif self._state == STATE_SCRIPT_HDR:
                 needLine = True
@@ -753,7 +731,7 @@ class KickstartParser:
             elif self._state == STATE_END:
                 break
 
-    def readKickstartFromString (self, str, reset=True):
+    def readKickstartFromString (self, s, reset=True):
         """Process a kickstart file, provided as the string str."""
         if reset:
             self._reset()
@@ -761,8 +739,8 @@ class KickstartParser:
         # Add a "" to the end of the list so the string reader acts like the
         # file reader and we only get StopIteration when we're after the final
         # line of input.
-        i = iter(str.splitlines(True) + [""])
-        self._stateMachine (lambda: i.next())
+        i = iter(s.splitlines(True) + [""])
+        self._stateMachine (i.next)
 
     def readKickstart(self, f, reset=True):
         """Process a kickstart file, given by the filename f."""
@@ -787,7 +765,7 @@ class KickstartParser:
         try:
             fh = urlopen(f)
         except grabber.URLGrabError, e:
-            raise IOError, formatErrorMsg(0, msg=_("Unable to open input kickstart file: %s") % e.strerror)
+            raise KickstartError, formatErrorMsg(0, msg=_("Unable to open input kickstart file: %s") % e.strerror)
 
-        self._stateMachine (lambda: fh.readline())
+        self._stateMachine (fh.readline)
         fh.close()
